Module strings

Module strings 

String manipulation utilities String utilities for safe C string handling.

Structs

BStr
Borrowed byte string backed by pool memory
BStrUtf8
UTF-8 validated borrowed string backed by pool memory
PoolString
Safe wrapper for pool-allocated C strings

Functions

make_cstring
Create a pool-allocated C string from a Rust string
pmemdup
Copy bytes into pool-allocated memory (not null-terminated)
pstrdup
Duplicate a Rust string into pool-allocated memory as a C string
pstrdup_raw
Get raw pointer version (for advanced users)
pstrndup
Duplicate a limited portion of a Rust string into pool-allocated memory